$set 3 #Configmenu

$ #ConfigOptions
# 
$ #FocusModel
#  
$ #WindowPlacement
#  
$ #ImageDithering
#  
$ #OpaqueMove
#     
$ #FullMax
#  
$ #FocusNew
#     
$ #FocusLast
#      
$ #DisableBindings
# Scroll Lock   
$ #ClickToFocus
#   
$ #SloppyFocus
#   
$ #AutoRaise
# 
$ #ClickRaise
#   
$ #SmartRows
# ""  ( )
$ #SmartCols
# ""  ( )
$ #Cascade
# 
$ #LeftRight
#  
$ #RightLeft
#  
$ #TopBottom
#  
$ #BottomTop
#  
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
